# Mikidown

Mikidown is a note taking application with markdown support.

> Mikidown was inspired by [Zim] and based on [ReText].

Install mikidown with
 
    python3-pip install mikidown

Run mikidown without installing

    git clone https://github.com/rnons/mikidown.git
    cd mikidown
    ./mikidown.py

## Features 

- Edit markdown with live preview
- Switch between Edit/View/LiveEdit mode
- All notes in one place, with multiple notebooks support
- Page cross-link
- Import from plain text files, export to HTML, PDF
- Customise your note style (by editing CSS file)

## Dependencies

- Python (>3.0)
- PyQt
- python-markdown
- python-whoosh

## Beautiful notes powered by markdown

In case you are unfamiliar with markdown, you can use this file ( **Help->README** ) as a simple reference to basic markdown syntax. However, I suggest you take a look at the complete [Markdown Syntax].

### Markdown extension

All python-markdown [extensions] are supported. To enable/disable extension, edit the `notebook.conf` file in your notebook folder.

    # notebook_folder/notebook.conf
    extensions=nl2br, strkundr, codehilite, fenced_code, headerid, headerlink, footnotes

### Mikidown Specific Syntax

1.  page cross link, all of the three will do 

    `[text](/parentNode/childNode/pageName)`
    `[text](/parentNode/childNode/pageName#anchor)`


2.  mikidown support both absolute and relative image path 

    `![text](file:///home/user/pic.png)` 
    `![text](pic.png)`     # path relative to notebook folder

    `Ctrl + I` or **Edit -> Insert Image** will bring up an **insert image** dialog.

3.  ins/del/bold/italics (better view in mikidown)

    - `~~delete~~`  will yield ~~delete~~
    - `__insert__` will yield __insert__
    - `**strong**` will yield **strong**
    - `//emphasis//` will yield //emphasis//

## Contributor

[ShadowKyogre]

[Fork and help] are much appreciated.

[Zim]: http://zim-wiki.org/
[ReText]: http://sourceforge.net/p/retext/
[Markdown Syntax]: http://daringfireball.net/projects/markdown/syntax
[Fork and help]: https://github.com/rnons/mikidown
[ShadowKyogre]: https://github.com/ShadowKyogre
[extensions]: http://pythonhosted.org/Markdown/extensions/index.html
